
# Slot: age_in_years


Number of years since birth

URI: [nwb_schema_language:age_in_years](https://w3id.org/p2p_ld/nwb-schema-language/age_in_years)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Integer](types/Integer.md)

## Parents


## Children


## Used by

 * [Namespaces](Namespaces.md)
